@@ -19,16 +19,13 @@
 # this program. If not, see <http://www.gnu.org/licenses/>
 
 kinobjects<- function(parent, type, systems,
-        layers = NA, sampling_times = NA)
+        layers = NA, sampling_times = NA, replicates = 1)
 {
         kinobjects <- list()
         for (system in systems) {
             kinobjects[[system]] <- kinobject(parent = parent, 
-                    type = type, system = system)
+                    type = type, system = system, sampling_times = sampling_times, replicates = replicates)
             if (!is.na(layers[1])) kinobjects[[system]]$layers = layers
-            if (!is.na(sampling_times[1])) {
-                    kinobjects[[system]]$sampling_times = layers
-            }
         }
         return(kinobjects)
 }
